@@ -41,8 +41,6 @@
 
 #define KCOMPLETION_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCOMPLETION_NO_DEPRECATED) && !defined(KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOMPLETION_NO_DEPRECATED
-#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
 #  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCOMPLETION_DEPRECATED
-#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCOMPLETION_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
